summaryrefslogtreecommitdiff
path: root/port/port_example.h
diff options
context:
space:
mode:
authorjorlow@chromium.org <jorlow@chromium.org@62dab493-f737-651d-591e-8d6aee1b9529>2011-03-22 23:24:02 +0000
committerjorlow@chromium.org <jorlow@chromium.org@62dab493-f737-651d-591e-8d6aee1b9529>2011-03-22 23:24:02 +0000
commit8303bb1b33a4db1d688d32f9be10976b0b54f209 (patch)
tree01802e7d30e43809b4a8c62a073c11c6037eb8f6 /port/port_example.h
parent6d243ebf79640525a94fab280efeb5a46c994af6 (diff)
downloadleveldb-8303bb1b33a4db1d688d32f9be10976b0b54f209.tar.gz
Pull from upstream.
git-svn-id: https://leveldb.googlecode.com/svn/trunk@14 62dab493-f737-651d-591e-8d6aee1b9529
Diffstat (limited to 'port/port_example.h')
-rw-r--r--port/port_example.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/port/port_example.h b/port/port_example.h
index ee25a01..cf72617 100644
--- a/port/port_example.h
+++ b/port/port_example.h
@@ -96,15 +96,16 @@ extern void SHA1_Hash(const char* data, size_t len, char* hash_array);
// ------------------ Compression -------------------
-// Store the lightweight compression of "input[0,input_length-1]" in *output.
-extern void Lightweight_Compress(const char* input, size_t input_length,
- std::string* output);
+// Store the snappy compression of "input[0,input_length-1]" in *output.
+// Returns false if snappy is not supported by this port.
+extern bool Snappy_Compress(const char* input, size_t input_length,
+ std::string* output);
-// Attempt to lightweight uncompress input[0,input_length-1] into *output.
+// Attempt to snappy uncompress input[0,input_length-1] into *output.
// Returns true if successful, false if the input is invalid lightweight
// compressed data.
-extern bool Lightweight_Uncompress(const char* input_data, size_t input_length,
- std::string* output);
+extern bool Snappy_Uncompress(const char* input_data, size_t input_length,
+ std::string* output);
// ------------------ Miscellaneous -------------------